@@ -1,6 +1,6 @@
 /*****************************************************************************
 *    Open LiteSpeed is an open source HTTP server.                           *
-*    Copyright (C) 2013 - 2018  LiteSpeed Technologies, Inc.                 *
+*    Copyright (C) 2013 - 2020  LiteSpeed Technologies, Inc.                 *
 *                                                                            *
 *    This program is free software: you can redistribute it and/or modify    *
 *    it under the terms of the GNU General Public License as published by    *
@@ -31,7 +31,7 @@ class L4Handler : public HioHandler
 
 public:
     L4Handler();
-    ~L4Handler() {};
+    ~L4Handler();
 
     int  init(HttpReq &req, const GSockAddr *pGSockAddr, const char *pIP,
               int iIpLen);
